;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xfe4a9b508512e2fdfce1970b8e4f9e2f . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x53b1f189c982d4783754fe0901b451e5 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x6651826a7f4cef7f4e7c189c77457558 . "./code.cg2js/cg-toolbar.fasl")
(#x15f1dc429fae2dadc5bd8941091d970e . "./code.cg2js/cg-chart-or-plot.fasl")
(#xe086def9d6e60eb23262ee30e4bfacb2 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xe24a86d96e27dbe00cb503fb10cb4e3d . "./code.cg2js/cg-class-grid.fasl")
(#x411578f2df1ec21acc2885314d1ada50 . "./code.cg2js/cg-tray.fasl")
(#x880f5f44453c3ff6d69733bcd2014cf1 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x9367c2a70e81579aad5cfa1f740475ab . "./code.cg2js/cg-class-support.fasl")
(#xf9172b45a705a57043ea396bda3d097f . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x8273122ada3c69d9464b7a3271671f83 . "./code.cg2js/cg-dropping-outline.fasl")
(#x1cd6c477cf83c114ba4cf05671eea1d7 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x8727eed2fc02ecde821b8a5687be2c69 . "./code.cg2js/cg-choice-list.fasl")
(#xa6c0d483b001e2dd865dd44b4190b7a7 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x5f32aabcc538f0fb26cc6aca51784ea3 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x027d08773a9ce2132acc553ab254215c . "./code.cg2js/cg-timer.fasl")
(#xd6754e1f65b171dce0736fed896b0602 . "./code.cg2js/cg-directory-dialog.fasl")
(#x5c15454a526760d8e9155f1f69a850dc . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x9f1609bf964223bede357598c1d0b0a1 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x9be4b27f91ea7879efe4956adf406f23 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xdc4808e737c19f6999cac0945ff49800 . "./code.cg2js/cg-html-widget.fasl")
(#x326d3bcac15dfde3c127a54b63eb2bb6 . "./code.cg2js/cg-selected-object.fasl")
(#xd7fb9f408c16f2e6f3a4092227f19c0f . "./code.cg2js/cg-lamp.fasl")
(#x6c2c6cc2bb9c20e9ecc6a270b96261ed . "./code.cg2js/cg-scroll-bar.fasl")
(#x80ea073c176c10471e3c8a05fea04bd6 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xc7ec5d1c76a6d03244b2ed038a9f9e0f . "./code.cg2js/cg-message-dialog.fasl")
(#x497799837423c065f18c295d608a7b73 . "./code.cg2js/cg-dde-utils.fasl")
(#x51a239928ee3e5c17b43bc76ee96dc94 . "./code.cg2js/cg-group-box.fasl")
(#x24126f1c03d36123f10844ebff39775d . "./code.cg2js/cg-find-string-dialog.fasl")
(#xc59f7b53cf588b1d16efb14d29cdf3f0 . "./code.cg2js/cg-split-bar.fasl")
(#x845f063db99f74d3a93126e026087a2a . "./code.cg2js/cg-radio-button.fasl")
(#xdea90f0e3ea10ba7168560da72ccabb8 . "./code.cg2js/cg-base.fasl")
(#x7d3a4700e50ce1cdd53fee4f2bb80421 . "./code.cg2js/cg-paren-matching.fasl")
(#x6973b4c9f715d67babecdc5f29c7490a . "./code.cg2js/cg-graphics-context.fasl")
(#x25366781a056a59ec92df081181eac7d . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x5755ff40a8369ff4aef7214b59b6f93f . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xa12b58e1d000631cdf54c45008ac347a . "./code.cg2js/cg-plot-widget.fasl")
(#x611561b102ab2a10760e788ba2bbb851 . "./code.cg2js/cg-dev.fasl")
(#xcbb077263e8dc6e30ec11010b3d06db1 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xfae7c6917512041f7e356dd88d624755 . "./code.cg2js/cg-tab-control.fasl")
(#x59014e8d13fb2aeea4f908a0c538965d . "./code.cg2js/cg-fill-texture.fasl")
(#xc2ca6832b6b6b6090a78f2f1c36e695e . "./code.cg2js/cg-menu-tooltip.fasl")
(#x28a74b0aed10c990284460666c7b978e . "./code.cg2js/cg-trackbar.fasl")
(#x128bef152da9f7ef5c6ec50ff371f2e2 . "./code.cg2js/cg-nodes.fasl")
(#xf0316208462950ee84a5fdfa21542604 . "./code.cg2js/cg-common-control.fasl")
(#x7d84698776a8ecb25b58e03f7e5e0a85 . "./code.cg2js/cg-list-view.fasl")
(#x06018be57c6eef40e41b71ae8a3530f7 . "./code.cg2js/cg-rich-edit.fasl")
(#x50b3f269723b0131112f45d3098e3376 . "./code.cg2js/cg-project-window.fasl")
(#x5bbc703b28568d13ef022d955dfe26af . "./code.cg2js/cg-item-list.fasl")
(#x55c4aefed47ebec302d051572040e38d . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x1b35c133c0e819bfd71ef8da0baed081 . "./code.cg2js/cg-get-position.fasl")
(#x086f0677d65f55c0aac747edb8077da3 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xdffc28b43d1f76ef2c490b908b42f787 . "./code.cg2js/cg-drawable.fasl")
(#xfd72f5fba0588c2370c3144c79be425a . "./code.cg2js/cg-lettered-menu.fasl")
(#x59fb6b92bd196375a0de7bc886da1ebc . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x0593cad17a3ae87c5a681dc2d173b86e . "./code.cg2js/cg-html-dialog.fasl")
(#x2565fc7b9e877b674f267c36df5db470 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x5ab2beeab10989a16f596827d858fbaf . "./code.cg2js/cg-utility-dialog.fasl")
(#xd16572638ee1243396e95211e38c5f7c . "./code.cg2js/cg-pixmap-widget.fasl")
(#x4fb93bd1c3932d449afdb17d8a77f3dd . "./code.cg2js/cg-property.fasl")
(#xe4f4af91c14b045d36dbcb0a97284e88 . "./code.cg2js/cg-menu.fasl")
(#xd4afd5faf8188be7667f1726b98639b6 . "./code.cg2js/cg-clipboard.fasl")
(#x8b2010f3c66c71e440d834c9a214a437 . "./code.cg2js/cg-toggling-widget.fasl")
(#x8114272902e8e51f5c531b98c71162b4 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xc63dc0b7bdff680e6e7558fe356d2c9b . "./code.cg2js/cg-template-string.fasl")
(#xdf7f1f5dba25be68a97d36e9f7ad04de . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xb356c023cbaad9162b3c0c65987df7c1 . "./code.cg2js/cg-os-window.fasl")
(#x4e55bb4b09d82d74d8bab44d51ab24bc . "./code.cg2js/cg-grid-widget.fasl")
(#x2ecf26965687a1dfaad23a166cc83e6a . "./code.cg2js/cg-picture-widget.fasl")
(#x4ecdd65bf121119f59a8cecd4a034561 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x98847a9d9db3424ec69ac450493d713a . "./code.cg2js/cg-static-text.fasl")
(#xa454003560e600d146a2607f2f436bc4 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xc5cc89a34d1235d5ed784b07ed4351e0 . "./code.cg2js/cg-text-widget.fasl")
(#xc50eb20f20311f7a1d0711fea8b63295 . "./code.cg2js/cg-calendar.fasl")
(#x15f48b06a6f7e6b808f0a34ae03ebc73 . "./code.cg2js/cg-check-box.fasl")
(#xff68f0a32a71135112bf475fbd2bfd6d . "./code.cg2js/cg-acache.fasl")
(#xe006a0209207bb95d5e3f36f76078836 . "./code.cg2js/cg-wrap-string.fasl")
(#x53bd11b723adc6e658b81d94ba03d329 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xbcf8fd6284da92b2977ec12135213576 . "./code.cg2js/cg-font-dialog.fasl")
(#xc02a347f8ad2371d776fcb0abc7b34b0 . "./code.cg2js/cg-outline.fasl")
(#xe5cb60a4d93076a6c8a0eb88ef9a5d15 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x04c502132760e0908f418f0ded5f6daa . "./code.cg2js/cg-status-bar.fasl")
(#xff772d3977adae5754f36d3ca31a1a85 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x5799755753fb301712266f18e7bf1737 . "./code.cg2js/cg-hotspot.fasl")
(#xa2191e22ca1e08bf699d15a4ac933132 . "./code.cg2js/cg-scaling-stream.fasl")
(#x921c77a614cd9bb39ab8cb8bdf7d387f . "./code.cg2js/cg-icon-pixmap.fasl")
(#x480b5ee9a13a2cf2da88d41681bb3ca7 . "./code.cg2js/cg-file-dialog.fasl")
(#xf4349aa95bb3e1483d9fd6bab9e75bba . "./code.cg2js/cg-color-dialog.fasl")
(#x6ca5d3bbb3882110253ccf2a4aec80eb . "./code.cg2js/cg-get-pixmap.fasl")
(#x32ae4c9122b459aa4dd7e64e18cf0982 . "./code.cg2js/cg-object-editor.fasl")
(#xc1cf6ee121ec3699281851056065981e . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x66e84165b54504194591e66b6fe2a089 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x33b9952a3574ccf94411cf8d6d6ba6a3 . "./code.cg2js/cg-pixmap.fasl")
(#x97e3a808b713289d023aa57dfec0231e . "./code.cg2js/cg-intersect.fasl")
(#x6274a443de9249e29172cbc2b5a402c9 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xfa72dcb9506ea47b4f816d3640de6363 . "./code.cg2js/cg-icon.fasl")
(#x8cbfce75b9d8a342cad5dd62637b8539 . "./code.cg2js/cg-yes-no-string.fasl")
(#xeaeb7b8edc01ea79c2cbefd14c58ae23 . "./code.cg2js/cg-text-or-combo.fasl")
(#x8872604d8cedeb570fdc29b8bccf17a6 . "./code.cg2js/cg.fasl")
(#x61998c828fed7293c8258adc359b8e55 . "./code.cg2js/cg-dialog-item.fasl")
(#x81b74c0670ee0a8e9b0a0bf8071165e0 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x673c82ddd5b12ecbfac3c7ffa2276146 . "./code.cg2js/cg-caret.fasl")
(#x0eebf2dd584c7cfe67656535a8e16a76 . "./code.cg2js/cg-editable-text.fasl")
(#x67fee7df14cdd9bd30be3092b4b97822 . "./code.cg2js/cg-choose-printer.fasl")
(#xa245bfbeffed3f8eaaadca4f2b7610c5 . "./code.cg2js/cg-yes-no-list.fasl")
(#x08fb69d7a92568a141e4743bed88318f . "./code.cg2js/cg-intersect-posbox.fasl")
(#xf71a2c008d45b55d4e34b2adcf5a1d0e . "./code.cg2js/cg-tooltip.fasl")
(#x1817aec156c05dfb5a0a9ecd34878110 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x4302d083bb0be3588b6a3d08ac75d31a . "./code.cg2js/cg-combo-box.fasl")
(#x3d37deafde2f372ffc06bdd339fd9e24 . "./code.cg2js/cg-curve.fasl")
(#xa9307030b9fb8a2c3282cff8f76165f5 . "./code.cg2js/cg-web-browser.fasl")
(#xfa12a0cc5b5fa16e9938d0cfe7fe83f7 . "./code.cg2js/cg-printing.fasl")
(#xce2decf94f805f5d86a8154c229818dc . "./code.cg2js/cg-lisp-widget.fasl")
(#x27ecdea60186e47ca412aa5561674885 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x191b32cae59e2a1de13fa7487715b3af . "./code.cg2js/cg-palette.fasl")
(#x83a2304e0d66a27b731c6c0e64f95908 . "./code.cg2js/cg-os-widget.fasl")
(#x68bc4e78ec7d10784018b832c12cf4c9 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xb36977dcbc9e951ac740f3259e175c5e . "./code.cg2js/cg-pixmap-printing.fasl")
(#xecc557e6906a9866e51ffdfeb1e479c2 . "./code.cg2js/cg-button.fasl")
(#x6074c0624078d3924af2ce5ecabe6deb . "./code.cg2js/cg-edit-in-place.fasl")
(#x5818c11ec7d56878957d42276b67cce7 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xa5fcf28bdadd64ebe61b7fdb6662a569 . "./code.cg2js/cg-comtab.fasl")
(#x43215f88b95aa658985fdfe9c1c8eb16 . "./code.cg2js/cg-string-dialog.fasl")
(#x08f29ff0eb2104860edd603240820a3c . "./code.cg2js/cg-header-control.fasl")
(#x6239dfcc92e0c467f6ece04178e37181 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xeac9da1df9e12c8c28133575df9e147c . "./code.cg2js/cg-up-down-control.fasl")
(#xd40d0efa31532c9738f2b59da7d88f55 . "./code.cg2js/cg-layout.fasl")
(#xf2bcc1deae63c84fde056066413fc71b . "./code.cg2js/cg-chart-widget.fasl")
(#x2526d2af8a01505d2d0c3ef051a69bc4 . "./code.cg2js/cg-lisp-text.fasl")
(#x286585d751591c3117934351834730ed . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x770bea50f911fca0baa5752fa8d4cd1b . "./code.cg2js/cg-progress-indicator.fasl")
(#xaba2498f361f6442574ff6f5a6152db8 . "./code.idejs/ide-inspector.fasl")
(#xa8e6e31422e40a022690a8d00c33a07a . "./code.idejs/ide-grapher.fasl")
(#x0c538867786cf2900ffa53a828226182 . "./code.idejs/ide-base.fasl")
(#x6b9c1364c75bb10da3336989de7cef5e . "./code.idejs/ide-keyshort.fasl")
(#x73a39c5277e9cc371c24d20632849c60 . "./code.idejs/ide-dev.fasl")
(#x53ea5670caba429a666429017c440741 . "./code.idejs/ide-class-browser.fasl")
(#x99e588b371394be27df3491cddb612a3 . "./code.idejs/ide-package-list.fasl")
(#x11cce9e2fb1517bc051e31efbffcdebc . "./code.idejs/ide-intro.fasl")
(#x83205b6b12774dfbab9cb76d2bbf6d8d . "./code.idejs/ide-class-grapher.fasl")
(#xeb63b0af7f5afbb021c3a29a1b38af0b . "./code.idejs/ide-window-list.fasl")
(#x59df1697393b0fe773e2ddfb3fc427c4 . "./code.idejs/ide-find-definitions.fasl")
(#xdfcf33af33d891df8a73052a5654c7b5 . "./code.idejs/ide-trace.fasl")
(#x8c00577bd24ed73984141f87877eb2ae . "./code.idejs/ide-editor.fasl")
(#xf18283edc93965d4fb282a3188973d70 . "./code.idejs/ide-patch-dialog.fasl")
(#x0c2403ababf375dda2b68852ea0c71e5 . "./code.idejs/ide-project.fasl")
(#xdf09f9e9613a5224736c234801276894 . "./code.idejs/ide.fasl")
(#x65d3cf9e77883e413d804603496b0f2c . "./code.idejs/ide-apropos.fasl")
(#x579ff4d94f969cdfc076a9f330e72fe8 . "./code.idejs/ide-acache.fasl")
(#x30b0f8a717143a6f7b32fa472c844e87 . "./code.idejs/ide-clipboard.fasl")
(#x02d1acddf610d2c0000f92d085abc156 . "./code.idejs/ide-process-browser.fasl")
(#xd34d43f97d2d471a9364bba0105d12cd . "./code.idejs/ide-find-in-files.fasl")
(#x197e05c35e53a2b82a1d546f0db91cc8 . "./code.idejs/ide-form.fasl")
(#x6b76f90a8ca2072ab626fadb3f0b4599 . "./code.idejs/ide-navigator.fasl")
(#xeb5b70ef6a4ced03becd92b82d3b0061 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
